@@ -75,6 +75,8 @@ __all__ = [
     "argmax",
     "sum",
     "nansum",
+    "prod",
+    "nanprod",
     "mean",
     "nanmean",
     "std",
@@ -979,6 +981,30 @@ def nansum(x, **kw_args):
     return B.sum(x, **kw_args)
 
 
+@dispatch
+@abstract()
+def prod(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
+    """Product of all elements in a tensor, possibly along an axis.
+
+    Args:
+        a (tensor): Tensor.
+        axis (int, optional): Optional axis.
+        squeeze (bool, optional): Squeeze the dimension after the reduction. Defaults
+            to `True`.
+
+    Returns:
+        tensor: Reduced tensor.
+    """
+
+
+@dispatch
+def nanprod(x, **kw_args):
+    """Like :func:`prod`, but ignores `NaN`s."""
+    available = ~B.isnan(x)
+    x = B.where(available, x, B.one(x))
+    return B.prod(x, **kw_args)
+
+
 @dispatch
 @abstract()
 def mean(a: Numeric, axis=None, squeeze=True):  # pragma: no cover
