@@ -237,6 +237,11 @@ def sum(a: Numeric, axis=None, squeeze=True):
     return jnp.sum(a, axis=axis, keepdims=not squeeze)
 
 
+@dispatch
+def prod(a: Numeric, axis=None, squeeze=True):
+    return jnp.prod(a, axis=axis, keepdims=not squeeze)
+
+
 @dispatch
 def mean(a: Numeric, axis=None, squeeze=True):
     return jnp.mean(a, axis=axis, keepdims=not squeeze)
