@@ -303,13 +303,10 @@ def test_cast_shape_element(dtype, check_lazy_shapes):
         B.sign,
         B.exp,
         B.sin,
-        B.arcsin,
         B.cos,
-        B.arccos,
         B.tan,
         B.arctan,
         B.tanh,
-        B.arctanh,
         B.erf,
         B.sigmoid,
         B.softplus,
@@ -329,6 +326,13 @@ def test_unary_positive(f, check_lazy_shapes):
     check_function(f, (PositiveTensor(2, 3),))
 
 
+@pytest.mark.parametrize("f", [B.arcsin, B.arccos, B.arctanh])
+def test_unary_unit_interval(f, check_lazy_shapes):
+    check_function(f, (PositiveTensor(upper=1),))
+    check_function(f, (PositiveTensor(2, upper=1),))
+    check_function(f, (PositiveTensor(2, 3, upper=1),))
+
+
 @pytest.mark.parametrize("a", [0, -1, 1])
 def test_softplus_correctness(a, check_lazy_shapes):
     approx(B.softplus(a), np.log(1 + np.exp(a)))
@@ -356,6 +360,8 @@ def test_binary_positive_first(f, check_lazy_shapes):
         (B.min, True),
         (B.max, True),
         (B.sum, True),
+        (B.prod, True),
+        (B.nanprod, True),
         (B.nansum, True),
         (B.mean, True),
         (B.nanmean, True),
@@ -387,7 +393,7 @@ def test_reductions(f, check_squeeze, check_lazy_shapes):
 
 @pytest.mark.parametrize(
     "f, f_ref",
-    [(B.nansum, B.sum), (B.nanmean, B.mean), (B.nanstd, B.std)],
+    [(B.nansum, B.sum), (B.nanprod, B.prod), (B.nanmean, B.mean), (B.nanstd, B.std)],
 )
 def test_nanreductions(f, f_ref, check_lazy_shapes):
     # Check consistency.
